#include <WScom.h>
#include <WSCfunctionList.h>
#include <WSCbase.h>

/**/

#include "Common.h"

/**/

//----------------------------------------------------------
//Function for the event procedure
//----------------------------------------------------------
void CnfNameListSelect(WSCbase* object){
  //do something...
	WSCstring name = Cnfcomb_NameList->getProperty( WSNlabelString );
	Cnfvifi_Name->setProperty( WSNlabelString, name );

	WSCstring url = gUrl.GetUrl( name );
	Cnfvifi_Url->setProperty( WSNlabelString, url );

	bool flag = gUrl.GetFlagDownload( name );
	Cnfvtog_Download->setStatus( flag );

	long en = gUrl.GetEncoding( name );
	Cnfcomb_Encoding->setProperty( WSNlabelString,
		ConvEncodingToStr( en ) );

	long skipArt = gUrl.GetSkipArt( name );
	Cnfvifi_SkipArt->setProperty( WSNlabelString, (WSCstring)skipArt );
	Cnfvsli_SkipArt->setProperty( WSNvalue, skipArt );

	long order = gUrl.GetN( name );
	Cnfvlab_Order->setProperty( WSNlabelString, order );
}
static WSCfunctionRegister  op("CnfNameListSelect",(void*)CnfNameListSelect);
